==> haskell-hspec-2.4.4-4-i686.pkg.tar.xz: usr/share/haskell/register/haskell-hspec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec
version: 2.4.4
id: hspec-2.4.4-AbAQl30vOAI9ZT0LBY4O8E
key: hspec-2.4.4-AbAQl30vOAI9ZT0LBY4O8E
license: MIT
copyright: (c) 2011-2017 Simon Hengel,
           (c) 2011-2012 Trystan Spangler,
           (c) 2011 Greg Weber
maintainer: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: http://hspec.github.io/
synopsis: A Testing Framework for Haskell
description:
    Hspec is a testing framework for Haskell. It is inspired by
    the Ruby library RSpec. Some of Hspec'\''s distinctive features
    are:
    .
    * a friendly DSL for defining tests
    .
    * integration with QuickCheck, SmallCheck, and HUnit
    .
    * parallel test execution
    .
    * automatic discovery of test files
    .
    The Hspec Manual is at <http://hspec.github.io/>.
category: Testing
exposed: True
indefinite: False
exposed-modules:
    Test.Hspec Test.Hspec.Core Test.Hspec.Discover
    Test.Hspec.Formatters Test.Hspec.HUnit Test.Hspec.QuickCheck
    Test.Hspec.Runner
hidden-modules: Paths_hspec
abi: 8c2051b4be421c08d63a14910eda77ee
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/hspec-2.4.4
library-dirs: /usr/lib/ghc-8.2.1/site-local/hspec-2.4.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/hspec-2.4.4
hs-libraries: HShspec-2.4.4-AbAQl30vOAI9ZT0LBY4O8E
depends:
    base-4.10.0.0 hspec-core-2.4.4-FTBFvC7qw2S4F0s3HJygaa
    hspec-discover-2.4.4-IItbyzxoQ94KZ3DWPccN8F
    hspec-expectations-0.8.2-4v0D3TYQPlY2sJs9cyEclt
    transformers-0.5.2.0 QuickCheck-2.10.0.1-DTIBC3CyU6p3h4xSnOjkg1
    HUnit-1.6.0.0-32Hmh42Ovy04fXZEjkNwW3
    call-stack-0.1.0-9jal1kz08FU8PWnIBPoZ86
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             hspec-core-2.4.4-FTBFvC7qw2S4F0s3HJygaa=d6e76d4d88f1f8f258296beb940926e4
             hspec-discover-2.4.4-IItbyzxoQ94KZ3DWPccN8F=fcd66ab641d8717f1370f019285f7028
             hspec-expectations-0.8.2-4v0D3TYQPlY2sJs9cyEclt=09cca836cd3c3bccf406f2b40e0a2223
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             QuickCheck-2.10.0.1-DTIBC3CyU6p3h4xSnOjkg1=2c4212a9c69c9d234eb81396b5fd082b
             HUnit-1.6.0.0-32Hmh42Ovy04fXZEjkNwW3=255da28eff8ebcc8245a3b98dfe660e4
             call-stack-0.1.0-9jal1kz08FU8PWnIBPoZ86=074cd9d4520ab1fa3869b4e9283eb803
haddock-interfaces: /usr/share/doc/haskell-hspec/html/hspec.haddock
haddock-html: /usr/share/doc/haskell-hspec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-2.4.4-5-i686.pkg.tar.xz: usr/share/haskell/register/haskell-hspec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec
version: 2.4.4
id: hspec-2.4.4-IJZGHSBanYvBPosV0gTjfV
key: hspec-2.4.4-IJZGHSBanYvBPosV0gTjfV
license: MIT
copyright: (c) 2011-2017 Simon Hengel,
           (c) 2011-2012 Trystan Spangler,
           (c) 2011 Greg Weber
maintainer: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: http://hspec.github.io/
synopsis: A Testing Framework for Haskell
description:
    Hspec is a testing framework for Haskell. It is inspired by
    the Ruby library RSpec. Some of Hspec'\''s distinctive features
    are:
    .
    * a friendly DSL for defining tests
    .
    * integration with QuickCheck, SmallCheck, and HUnit
    .
    * parallel test execution
    .
    * automatic discovery of test files
    .
    The Hspec Manual is at <http://hspec.github.io/>.
category: Testing
exposed: True
indefinite: False
exposed-modules:
    Test.Hspec Test.Hspec.Core Test.Hspec.Discover
    Test.Hspec.Formatters Test.Hspec.HUnit Test.Hspec.QuickCheck
    Test.Hspec.Runner
hidden-modules: Paths_hspec
abi: 6cb17a2d44131105592269d4c69f08c2
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/hspec-2.4.4
library-dirs: /usr/lib/ghc-8.2.1/site-local/hspec-2.4.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/hspec-2.4.4
hs-libraries: HShspec-2.4.4-IJZGHSBanYvBPosV0gTjfV
depends:
    base-4.10.0.0 hspec-core-2.4.4-HCSTC9t7mbfETD97riQOBD
    hspec-discover-2.4.4-IItbyzxoQ94KZ3DWPccN8F
    hspec-expectations-0.8.2-4v0D3TYQPlY2sJs9cyEclt
    transformers-0.5.2.0 QuickCheck-2.10.1-KIwpOgIMAPpCfx99HppzCX
    HUnit-1.6.0.0-32Hmh42Ovy04fXZEjkNwW3
    call-stack-0.1.0-9jal1kz08FU8PWnIBPoZ86
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             hspec-core-2.4.4-HCSTC9t7mbfETD97riQOBD=6299ed9f5d5847e2c1b2076084e66ac3
             hspec-discover-2.4.4-IItbyzxoQ94KZ3DWPccN8F=fcd66ab641d8717f1370f019285f7028
             hspec-expectations-0.8.2-4v0D3TYQPlY2sJs9cyEclt=09cca836cd3c3bccf406f2b40e0a2223
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             QuickCheck-2.10.1-KIwpOgIMAPpCfx99HppzCX=31c7a57798b8306ee987164ad717d7a8
             HUnit-1.6.0.0-32Hmh42Ovy04fXZEjkNwW3=255da28eff8ebcc8245a3b98dfe660e4
             call-stack-0.1.0-9jal1kz08FU8PWnIBPoZ86=074cd9d4520ab1fa3869b4e9283eb803
haddock-interfaces: /usr/share/doc/haskell-hspec/html/hspec.haddock
haddock-html: /usr/share/doc/haskell-hspec/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
